cmd

package
v0.4.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IncludedPlugins

func IncludedPlugins() []string

IncludedPlugins returns application plugins accepted by Omeka S contexts.

func RegisterCommands

func RegisterCommands(s *plugin.SDK)

RegisterCommands registers Omeka S commands with the plugin SDK.

Types

This section is empty.

Jump to